@@ -22,7 +22,10 @@ test_that("time.character", {
   expect_identical(dtt_time(NA_character_), NA_hms_)
   expect_identical(dtt_time("01:02:03"), hms::as_hms("01:02:03"))
   expect_identical(dtt_time("01:02:03.99999"), hms::as_hms("01:02:03"))
-  expect_identical(dtt_time(c("01:02:03", NA)), c(hms::as_hms("01:02:03"), NA_hms_))
+  expect_identical(
+    dtt_time(c("01:02:03", NA)),
+    c(hms::as_hms("01:02:03"), NA_hms_)
+  )
 })
 
 test_that("time.Date", {
@@ -59,7 +62,9 @@ test_that("time.POSIXct", {
     hms::as_hms("23:59:59")
   )
   expect_identical(
-    dtt_time(c(as.POSIXct("1970-01-03 23:59:59", tz = "Etc/GMT+8"), NA_POSIXct_)),
+    dtt_time(
+      c(as.POSIXct("1970-01-03 23:59:59", tz = "Etc/GMT+8"), NA_POSIXct_)
+    ),
     c(hms::as_hms("23:59:59"), NA_hms_)
   )
 })
@@ -76,7 +81,11 @@ test_that("time.POSIXlt", {
     hms::as_hms("23:59:59")
   )
   expect_identical(
-    dtt_time(as.POSIXlt(c(as.POSIXct("1970-01-03 23:59:59", tz = "Etc/GMT+8"), NA_POSIXct_))),
+    dtt_time(
+      as.POSIXlt(
+        c(as.POSIXct("1970-01-03 23:59:59", tz = "Etc/GMT+8"), NA_POSIXct_)
+      )
+    ),
     c(hms::as_hms("23:59:59"), NA_hms_)
   )
 })
@@ -85,7 +94,10 @@ test_that("time.hms", {
   expect_identical(dtt_time(hms::as_hms(1)[-1]), hms::as_hms(1)[-1])
   expect_identical(dtt_time(NA_hms_), NA_hms_)
   expect_identical(dtt_time(hms::as_hms("01:02:03")), hms::as_hms("01:02:03"))
-  expect_identical(dtt_time(hms::as_hms("01:02:03.99999")), hms::as_hms("01:02:03"))
+  expect_identical(
+    dtt_time(hms::as_hms("01:02:03.99999")),
+    hms::as_hms("01:02:03")
+  )
   expect_identical(
     dtt_time(c(hms::as_hms("01:02:03"), NA_hms_)),
     c(hms::as_hms("01:02:03"), NA_hms_)
@@ -98,22 +110,37 @@ test_that("set_time Date", {
     as.POSIXct("2001-01-01 07:08:09", tz = dtt_default_tz())
   )
   expect_equal(
-    dtt_set_time(as.Date(c("2001-01-01", "2003-01-03")), hms::as_hms("07:08:09")),
-    as.POSIXct(c("2001-01-01 07:08:09", "2003-01-03 07:08:09"), tz = dtt_default_tz())
+    dtt_set_time(
+      as.Date(c("2001-01-01", "2003-01-03")),
+      hms::as_hms("07:08:09")
+    ),
+    as.POSIXct(
+      c("2001-01-01 07:08:09", "2003-01-03 07:08:09"),
+      tz = dtt_default_tz()
+    )
   )
 })
 
 test_that("set_time POSIXct", {
-  expect_equal(dtt_set_time(as.POSIXct("2001-01-01 04:05:06"), hms::as_hms("07:08:09")),
+  expect_equal(
+    dtt_set_time(as.POSIXct("2001-01-01 04:05:06"), hms::as_hms("07:08:09")),
     as.POSIXct("2001-01-01 07:08:09"),
     ignore_attr = TRUE
   )
-  expect_equal(dtt_set_time(as.POSIXct(c("2001-01-01 04:05:06", "2003-01-03 04:05:06")), hms::as_hms("07:08:09")),
+  expect_equal(
+    dtt_set_time(
+      as.POSIXct(c("2001-01-01 04:05:06", "2003-01-03 04:05:06")),
+      hms::as_hms("07:08:09")
+    ),
     as.POSIXct(c("2001-01-01 07:08:09", "2003-01-03 07:08:09")),
     ignore_attr = TRUE
   )
 
-  expect_equal(dtt_set_time(as.POSIXct("2001-01-01 04:05:06", tz = "Etc/GMT-7"), hms::as_hms("07:08:09")),
+  expect_equal(
+    dtt_set_time(
+      as.POSIXct("2001-01-01 04:05:06", tz = "Etc/GMT-7"),
+      hms::as_hms("07:08:09")
+    ),
     as.POSIXct("2001-01-01 07:08:09", tz = "Etc/GMT-7"),
     ignore_attr = TRUE
   )
